@@ -35,10 +35,16 @@ class TcpConnectionFactory(_ConnectionFactory, _Generic[T]):
         self,
         stop_sig: _asyncio.Event,
         manager: _ConnectionManager,
+        started_sem: _asyncio.Semaphore,
         *args,
         **kwargs,
     ) -> _ServerTask:
         """Create a task that will run a connection server."""
 
         assert not [*args], "Only keyword arguments are used!"
-        return self.kind.app(stop_sig, manager=manager, **kwargs)
+        return self.kind.app(
+            stop_sig,
+            manager=manager,
+            serving_callback=lambda _: started_sem.release(),
+            **kwargs,
+        )
